Usage
smacofRect(delta, ndim = 2, circle = c("none","row","column"), weightmat = NULL, init = NULL, verbose = FALSE, itmax = 1000, reg = 1e-6, eps = 1e-6)
unfolding(delta, ndim = 2, circle = c("none","row","column"), weightmat = NULL, init = NULL, verbose = FALSE, itmax = 1000, reg = 1e-6, eps = 1e-6)
Arguments
delta
Data frame or matrix of preferences, ratings, dissimilarities.
circle
If "column", the column configurations are restricted to be on a circle, if "row", row configurations are on a circle, if "none", there are no restrictions on row and column configurations
weightmat
Optional matrix with dissimilarity weights
init
Matrix with starting values for configurations (optional)
verbose
If TRUE, intermediate stress is printed out
itmax
Maximum number of iterations
reg
Regularization factor, prevents distances from being 0